@@ -1,4 +1,4 @@
-/* $OpenBSD: err.c,v 1.49 2022/08/29 06:49:24 jsing Exp $ */
+/* $OpenBSD: err.c,v 1.60 2024/03/02 11:37:13 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -122,12 +122,29 @@
 #include <openssl/err.h>
 #include <openssl/lhash.h>
 
+#include "crypto_local.h"
+
 DECLARE_LHASH_OF(ERR_STRING_DATA);
 DECLARE_LHASH_OF(ERR_STATE);
 
+typedef struct st_ERR_FNS ERR_FNS;
+
+typedef struct err_state_st {
+	CRYPTO_THREADID tid;
+	int err_flags[ERR_NUM_ERRORS];
+	unsigned long err_buffer[ERR_NUM_ERRORS];
+	char *err_data[ERR_NUM_ERRORS];
+	int err_data_flags[ERR_NUM_ERRORS];
+	const char *err_file[ERR_NUM_ERRORS];
+	int err_line[ERR_NUM_ERRORS];
+	int top, bottom;
+} ERR_STATE;
+
 static void err_load_strings(int lib, ERR_STRING_DATA *str);
 
+static ERR_STATE *ERR_get_state(void);
 static void ERR_STATE_free(ERR_STATE *s);
+
 #ifndef OPENSSL_NO_ERR
 static ERR_STRING_DATA ERR_str_libraries[] = {
 	{ERR_PACK(ERR_LIB_NONE,0,0),		"unknown library"},
@@ -300,31 +317,6 @@ err_fns_check(void)
 	CRYPTO_w_unlock(CRYPTO_LOCK_ERR);
 }
 
-/* API functions to get or set the underlying ERR functions. */
-
-const ERR_FNS *
-ERR_get_implementation(void)
-{
-	err_fns_check();
-	return err_fns;
-}
-
-int
-ERR_set_implementation(const ERR_FNS *fns)
-{
-	int ret = 0;
-
-	CRYPTO_w_lock(CRYPTO_LOCK_ERR);
-	/* It's too late if 'err_fns' is non-NULL. BTW: not much point setting
-	 * an error is there?! */
-	if (!err_fns) {
-		err_fns = fns;
-		ret = 1;
-	}
-	CRYPTO_w_unlock(CRYPTO_LOCK_ERR);
-	return ret;
-}
-
 /* These are the callbacks provided to "lh_new()" when creating the LHASH tables
  * internal to the "err_defaults" implementation. */
 
@@ -351,17 +343,14 @@ err_string_data_cmp(const ERR_STRING_DATA *a, const ERR_STRING_DATA *b)
 }
 static IMPLEMENT_LHASH_COMP_FN(err_string_data, ERR_STRING_DATA)
 
-static
-LHASH_OF(ERR_STRING_DATA) *int_err_get(int create)
+static LHASH_OF(ERR_STRING_DATA) *
+int_err_get(int create)
 {
 	LHASH_OF(ERR_STRING_DATA) *ret = NULL;
 
 	CRYPTO_w_lock(CRYPTO_LOCK_ERR);
-	if (!int_error_hash && create) {
-		CRYPTO_push_info("int_err_get (err.c)");
+	if (!int_error_hash && create)
 		int_error_hash = lh_ERR_STRING_DATA_new();
-		CRYPTO_pop_info();
-	}
 	if (int_error_hash)
 		ret = int_error_hash;
 	CRYPTO_w_unlock(CRYPTO_LOCK_ERR);
@@ -448,17 +437,14 @@ err_state_cmp(const ERR_STATE *a, const ERR_STATE *b)
 }
 static IMPLEMENT_LHASH_COMP_FN(err_state, ERR_STATE)
 
-static
-LHASH_OF(ERR_STATE) *int_thread_get(int create)
+static LHASH_OF(ERR_STATE) *
+int_thread_get(int create)
 {
 	LHASH_OF(ERR_STATE) *ret = NULL;
 
 	CRYPTO_w_lock(CRYPTO_LOCK_ERR);
-	if (!int_thread_hash && create) {
-		CRYPTO_push_info("int_thread_get (err.c)");
+	if (!int_thread_hash && create)
 		int_thread_hash = lh_ERR_STATE_new();
-		CRYPTO_pop_info();
-	}
 	if (int_thread_hash) {
 		int_thread_hash_references++;
 		ret = int_thread_hash;
@@ -580,6 +566,7 @@ build_SYS_str_reasons(void)
 	static char strerror_tab[NUM_SYS_STR_REASONS][LEN_SYS_STR_REASON];
 	int i;
 	static int init = 1;
+	int save_errno;
 
 	CRYPTO_r_lock(CRYPTO_LOCK_ERR);
 	if (!init) {
@@ -594,6 +581,8 @@ build_SYS_str_reasons(void)
 		return;
 	}
 
+	/* strerror(3) will set errno to EINVAL when i is an unknown errno. */
+	save_errno = errno;
 	for (i = 1; i <= NUM_SYS_STR_REASONS; i++) {
 		ERR_STRING_DATA *str = &SYS_str_reasons[i - 1];
 
@@ -610,6 +599,7 @@ build_SYS_str_reasons(void)
 		if (str->string == NULL)
 			str->string = "unknown";
 	}
+	errno = save_errno;
 
 	/* Now we still have SYS_str_reasons[NUM_SYS_STR_REASONS] = {0, NULL},
 	 * as required by ERR_load_strings. */
@@ -681,6 +671,7 @@ ERR_load_ERR_strings(void)
 
 	(void) pthread_once(&once, ERR_load_ERR_strings_internal);
 }
+LCRYPTO_ALIAS(ERR_load_ERR_strings);
 
 static void
 err_load_strings(int lib, ERR_STRING_DATA *str)
@@ -699,6 +690,7 @@ ERR_load_strings(int lib, ERR_STRING_DATA *str)
 	ERR_load_ERR_strings();
 	err_load_strings(lib, str);
 }
+LCRYPTO_ALIAS(ERR_load_strings);
 
 void
 ERR_unload_strings(int lib, ERR_STRING_DATA *str)
@@ -713,6 +705,7 @@ ERR_unload_strings(int lib, ERR_STRING_DATA *str)
 		str++;
 	}
 }
+LCRYPTO_ALIAS(ERR_unload_strings);
 
 void
 ERR_free_strings(void)
@@ -723,6 +716,7 @@ ERR_free_strings(void)
 	err_fns_check();
 	ERRFN(err_del)();
 }
+LCRYPTO_ALIAS(ERR_free_strings);
 
 /********************************************************/
 
@@ -744,6 +738,7 @@ ERR_put_error(int lib, int func, int reason, const char *file, int line)
 	err_clear_data(es, es->top);
 	errno = save_errno;
 }
+LCRYPTO_ALIAS(ERR_put_error);
 
 void
 ERR_clear_error(void)
@@ -758,6 +753,7 @@ ERR_clear_error(void)
 	}
 	es->top = es->bottom = 0;
 }
+LCRYPTO_ALIAS(ERR_clear_error);
 
 
 unsigned long
@@ -765,12 +761,14 @@ ERR_get_error(void)
 {
 	return (get_error_values(1, 0, NULL, NULL, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_get_error);
 
 unsigned long
 ERR_get_error_line(const char **file, int *line)
 {
 	return (get_error_values(1, 0, file, line, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_get_error_line);
 
 unsigned long
 ERR_get_error_line_data(const char **file, int *line,
@@ -778,6 +776,7 @@ ERR_get_error_line_data(const char **file, int *line,
 {
 	return (get_error_values(1, 0, file, line, data, flags));
 }
+LCRYPTO_ALIAS(ERR_get_error_line_data);
 
 
 unsigned long
@@ -785,12 +784,14 @@ ERR_peek_error(void)
 {
 	return (get_error_values(0, 0, NULL, NULL, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_peek_error);
 
 unsigned long
 ERR_peek_error_line(const char **file, int *line)
 {
 	return (get_error_values(0, 0, file, line, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_peek_error_line);
 
 unsigned long
 ERR_peek_error_line_data(const char **file, int *line,
@@ -798,18 +799,21 @@ ERR_peek_error_line_data(const char **file, int *line,
 {
 	return (get_error_values(0, 0, file, line, data, flags));
 }
+LCRYPTO_ALIAS(ERR_peek_error_line_data);
 
 unsigned long
 ERR_peek_last_error(void)
 {
 	return (get_error_values(0, 1, NULL, NULL, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_peek_last_error);
 
 unsigned long
 ERR_peek_last_error_line(const char **file, int *line)
 {
 	return (get_error_values(0, 1, file, line, NULL, NULL));
 }
+LCRYPTO_ALIAS(ERR_peek_last_error_line);
 
 unsigned long
 ERR_peek_last_error_line_data(const char **file, int *line,
@@ -817,6 +821,7 @@ ERR_peek_last_error_line_data(const char **file, int *line,
 {
 	return (get_error_values(0, 1, file, line, data, flags));
 }
+LCRYPTO_ALIAS(ERR_peek_last_error_line_data);
 
 static unsigned long
 get_error_values(int inc, int top, const char **file, int *line,
@@ -938,6 +943,7 @@ ERR_error_string_n(unsigned long e, char *buf, size_t len)
 		}
 	}
 }
+LCRYPTO_ALIAS(ERR_error_string_n);
 
 /* BAD for multi-threading: uses a local buffer if ret == NULL */
 /* ERR_error_string_n should be used instead for ret != NULL
@@ -953,25 +959,7 @@ ERR_error_string(unsigned long e, char *ret)
 
 	return ret;
 }
-
-LHASH_OF(ERR_STRING_DATA) *ERR_get_string_table(void)
-{
-	err_fns_check();
-	return ERRFN(err_get)(0);
-}
-
-LHASH_OF(ERR_STATE) *ERR_get_err_state_table(void)
-{
-	err_fns_check();
-	return ERRFN(thread_get)(0);
-}
-
-void
-ERR_release_err_state_table(LHASH_OF(ERR_STATE) **hash)
-{
-	err_fns_check();
-	ERRFN(thread_release)(hash);
-}
+LCRYPTO_ALIAS(ERR_error_string);
 
 const char *
 ERR_lib_error_string(unsigned long e)
@@ -988,6 +976,7 @@ ERR_lib_error_string(unsigned long e)
 	p = ERRFN(err_get_item)(&d);
 	return ((p == NULL) ? NULL : p->string);
 }
+LCRYPTO_ALIAS(ERR_lib_error_string);
 
 const char *
 ERR_func_error_string(unsigned long e)
@@ -1002,6 +991,7 @@ ERR_func_error_string(unsigned long e)
 	p = ERRFN(err_get_item)(&d);
 	return ((p == NULL) ? NULL : p->string);
 }
+LCRYPTO_ALIAS(ERR_func_error_string);
 
 const char *
 ERR_reason_error_string(unsigned long e)
@@ -1020,6 +1010,7 @@ ERR_reason_error_string(unsigned long e)
 	}
 	return ((p == NULL) ? NULL : p->string);
 }
+LCRYPTO_ALIAS(ERR_reason_error_string);
 
 void
 ERR_remove_thread_state(const CRYPTO_THREADID *id)
@@ -1035,16 +1026,16 @@ ERR_remove_thread_state(const CRYPTO_THREADID *id)
 	 * items reaches zero. */
 	ERRFN(thread_del_item)(&tmp);
 }
+LCRYPTO_ALIAS(ERR_remove_thread_state);
 
-#ifndef OPENSSL_NO_DEPRECATED
 void
 ERR_remove_state(unsigned long pid)
 {
 	ERR_remove_thread_state(NULL);
 }
-#endif
+LCRYPTO_ALIAS(ERR_remove_state);
 
-ERR_STATE *
+static ERR_STATE *
 ERR_get_state(void)
 {
 	static ERR_STATE fallback;
@@ -1075,7 +1066,7 @@ ERR_get_state(void)
 			ERR_STATE_free(ret); /* could not insert it */
 			return (&fallback);
 		}
-		/* If a race occured in this function and we came second, tmpp
+		/* If a race occurred in this function and we came second, tmpp
 		 * is the first one that we just replaced. */
 		if (tmpp)
 			ERR_STATE_free(tmpp);
@@ -1089,6 +1080,7 @@ ERR_get_next_error_library(void)
 	err_fns_check();
 	return ERRFN(get_next_lib)();
 }
+LCRYPTO_ALIAS(ERR_get_next_error_library);
 
 void
 ERR_set_error_data(char *data, int flags)
@@ -1106,6 +1098,7 @@ ERR_set_error_data(char *data, int flags)
 	es->err_data[i] = data;
 	es->err_data_flags[i] = flags;
 }
+LCRYPTO_ALIAS(ERR_set_error_data);
 
 void
 ERR_asprintf_error_data(char * format, ...)
@@ -1122,6 +1115,7 @@ ERR_asprintf_error_data(char * format, ...)
 	else
 		ERR_set_error_data(errbuf, ERR_TXT_MALLOCED|ERR_TXT_STRING);
 }
+LCRYPTO_ALIAS(ERR_asprintf_error_data);
 
 void
 ERR_add_error_vdata(int num, va_list args)
@@ -1164,6 +1158,7 @@ ERR_set_mark(void)
 	es->err_flags[es->top] |= ERR_FLAG_MARK;
 	return 1;
 }
+LCRYPTO_ALIAS(ERR_set_mark);
 
 int
 ERR_pop_to_mark(void)
@@ -1185,6 +1180,7 @@ ERR_pop_to_mark(void)
 	es->err_flags[es->top]&=~ERR_FLAG_MARK;
 	return 1;
 }
+LCRYPTO_ALIAS(ERR_pop_to_mark);
 
 void
 err_clear_last_constant_time(int clear)
