@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,19 +33,11 @@ public:
         registerAdaptor();
     }
 
-    ~DBusInstance()
-    {
-        unregisterAdaptor();
-    }
+    ~DBusInstance() { unregisterAdaptor(); }
 
-    void
-    Register(const int32_t& /*pid*/, const std::string& /*name*/)
-    {
-        ++count_;
-    }
+    void Register(const int32_t& /*pid*/, const std::string& /*name*/) { ++count_; }
 
-    void
-    Unregister(const int32_t& /*pid*/)
+    void Unregister(const int32_t& /*pid*/)
     {
         --count_;
 
