@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #endif
 
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #endif
 
 #ifdef _WIN32
@@ -79,7 +79,6 @@
 #include <cstring>
 #include <cerrno>
 #include <cstddef>
-#include <ciso646>
 
 #include <pj/ctype.h>
 #include <pjlib-util/md5.h>
@@ -218,11 +217,23 @@ createFileLink(const std::filesystem::path& linkFile, const std::filesystem::pat
     if (linkFile == target)
         return true;
     std::error_code ec;
-    if (std::filesystem::exists(linkFile, ec)) {
-        if (std::filesystem::is_symlink(linkFile, ec) && std::filesystem::read_symlink(linkFile, ec) == target)
+    // Use symlink_status() because exists() could return false for broken symlinks
+    auto status = std::filesystem::symlink_status(linkFile, ec);
+    if (status.type() != std::filesystem::file_type::not_found) {
+        if (status.type() == std::filesystem::file_type::symlink
+            && std::filesystem::read_symlink(linkFile, ec) == target) {
+            JAMI_DEBUG("createFileLink: {} symlink already points to target {}", linkFile, target);
             return true;
-        std::filesystem::remove(linkFile, ec);
+        }
+        // Remove any existing file or symlink before creating a new one, as create_symlink()
+        // will fail with "File exists" error if the linkFile path already exists.
+        if (status.type() == std::filesystem::file_type::regular
+            || status.type() == std::filesystem::file_type::symlink) {
+            std::filesystem::remove(linkFile, ec);
+        }
     }
+
+    // Try to create a hard link if requested; fall back to symlink on failure
     if (not hard or not createHardlink(linkFile, target))
         return createSymlink(linkFile, target);
     return true;
@@ -828,5 +839,40 @@ lastWriteTimeInSeconds(const std::filesystem::path& filePath)
     return std::chrono::duration_cast<std::chrono::seconds>(lastWrite.time_since_epoch()).count();
 }
 
+std::string
+getOrCreateLocalDeviceId()
+{
+    const auto& localDir = get_data_dir(); // ~/.local/share/jami/
+    auto fullIdPath = localDir / "local_device_id";
+    std::string localDeviceId;
+
+    if (std::filesystem::exists(fullIdPath)) {
+        // Get the id inside the file
+        std::ifstream inStream(fullIdPath);
+        std::getline(inStream, localDeviceId);
+        inStream.close();
+        if (!localDeviceId.empty())
+            return localDeviceId;
+    }
+
+    // Generate a random hex string
+    {
+        std::random_device randomDevice;
+        localDeviceId = to_hex_string(std::uniform_int_distribution<uint64_t>()(randomDevice));
+    }
+
+    // Create a new file and write the id in it
+    std::error_code ec;
+    std::filesystem::create_directories(localDir, ec);
+    std::ofstream outStream(fullIdPath);
+    if (outStream) {
+        outStream << localDeviceId << std::endl;
+        outStream.close();
+    } else {
+        JAMI_ERROR("Unable to create local device id file: {}", fullIdPath);
+    }
+    return localDeviceId;
+}
+
 } // namespace fileutils
 } // namespace jami
