@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -448,13 +448,15 @@ AccountManager::onPeerMessage(
     std::function<void(const std::shared_ptr<dht::crypto::Certificate>& crt, const dht::InfoHash& peer_account)>&& cb)
 {
     // quick check in case we already explicilty banned this device
-    auto trustStatus = getCertificateStatus(peer_device.toString());
+    auto trustStatus = getCertificateStatus(peer_device.getLongId().toString());
     if (trustStatus == dhtnet::tls::TrustStore::PermissionStatus::BANNED) {
-        JAMI_WARNING("[Account {}] [Auth] Discarding message from banned device {}", accountId_, peer_device.toString());
+        JAMI_WARNING("[Account {}] [Auth] Discarding message from banned device {}",
+                     accountId_,
+                     peer_device.getLongId().to_view());
         return;
     }
 
-    findCertificate(peer_device.getId(),
+    findCertificate(peer_device.getLongId(),
                     [this, cb = std::move(cb), allowPublic](const std::shared_ptr<dht::crypto::Certificate>& cert) {
                         dht::InfoHash peer_account_id;
                         if (onPeerCertificate(cert, allowPublic, peer_account_id)) {
@@ -505,7 +507,7 @@ AccountManager::removeContact(const std::string& uri, bool banned)
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] removeContact: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] removeContact: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
@@ -521,7 +523,7 @@ AccountManager::removeContactConversation(const std::string& uri)
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] removeContactConversation: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] removeContactConversation: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
@@ -537,7 +539,7 @@ AccountManager::updateContactConversation(const std::string& uri, const std::str
 {
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] updateContactConversation: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] updateContactConversation: invalid contact URI: {}", accountId_, uri);
         return;
     }
     if (not info_) {
@@ -582,7 +584,7 @@ AccountManager::getContactDetails(const std::string& uri) const
     }
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] getContactDetails: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] getContactDetails: invalid contact URI: {}", accountId_, uri);
         return {};
     }
     return info_->contacts->getContactDetails(h);
@@ -597,7 +599,7 @@ AccountManager::getContactInfo(const std::string& uri) const
     }
     dht::InfoHash h(uri);
     if (not h) {
-        JAMI_ERROR("[Account {}] getContactInfo: invalid contact URI", accountId_);
+        JAMI_ERROR("[Account {}] getContactInfo: invalid contact URI: {}", accountId_, uri);
         return {};
     }
     return info_->contacts->getContactInfo(h);
@@ -732,7 +734,7 @@ AccountManager::sendTrustRequest(const std::string& to, const std::string& convI
                      dev->getLongId(),
                      payload.size(),
                      to);
-        dht_->putEncrypted(dht::InfoHash::get("inbox:" + dev->getId().toString()),
+        dht_->putEncrypted(dht::InfoHash::get(concat("inbox:"sv, dev->getId().to_view())),
                            dev,
                            dht::TrustRequest(DHT_TYPE_NS, convId, payload),
                            [to, size = payload.size()](bool ok) {
