@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -65,16 +65,26 @@ public:
 
     std::string getId() const { return id_; };
 
+    /**
+     * Return the ring-buffer ID that other components should read from
+     * to get this input's audio data.  For capture streams this is the
+     * target device ID (e.g. "desktop"); for files it is the
+     * AudioInput's own ID (where the decoder writes).
+     */
+    std::string getSourceRingBufferId() const { return sourceRingBufferId_; };
+
 private:
     void readFromDevice();
     void readFromFile();
     void readFromQueue();
     bool initDevice(const std::string& device);
     bool initFile(const std::string& path);
+    bool initCapture(const std::string& device);
     bool createDecoder();
     void frameResized(std::shared_ptr<AudioFrame>&& ptr);
 
     std::string id_;
+    std::string sourceRingBufferId_; // ring buffer ID to read this input's audio from
     std::shared_ptr<RingBuffer> ringBuf_;
     bool muteState_ {false};
     uint64_t sent_samples = 0;
