@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #include "media_encoder.h"
 #include "media_buffer.h"
 
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "fileutils.h"
 #include "logger.h"
 #include "manager.h"
