@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "media_buffer.h"
 #include "logger.h"
 #include "noncopyable.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "jami/videomanager_interface.h"
 #include "libav_utils.h"
 #include "video_scaler.h"
@@ -42,7 +42,7 @@
 #ifndef _WIN32
 #include <sys/mman.h>
 #endif
-#include <ciso646> // fix windows compiler bug
+
 #include <fcntl.h>
 #include <cstdio>
 #include <sstream>
@@ -478,7 +478,9 @@ SinkClient::setFrameSize(int width, int height)
 void
 SinkClient::setCrop(int x, int y, int w, int h)
 {
-    JAMI_DBG("[Sink:%p] Change crop to [%dx%d at (%d, %d)]", this, w, h, x, y);
+    if (x != crop_.x || y != crop_.y || w != crop_.w || h != crop_.h) {
+        JAMI_DBG("[Sink:%p] Change crop to [%dx%d at (%d, %d)]", this, w, h, x, y);
+    }
     crop_.x = x;
     crop_.y = y;
     crop_.w = w;
