@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,11 +19,12 @@
 #define __PREFERENCE_H__
 
 #include "config/serializable.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include <string>
 #include <map>
 #include <set>
 #include <vector>
+#include <chrono>
 
 namespace YAML {
 class Emitter;
@@ -59,13 +60,17 @@ public:
 
     void setAccountOrder(const std::string& ord) { accountOrder_ = ord; }
 
+    bool isAccountPending(const std::string& accountId) const;
+    bool addPendingAccountId(const std::string& accountId);
+    bool removePendingAccountId(const std::string& accountId);
+
     int getHistoryLimit() const { return historyLimit_; }
 
     void setHistoryLimit(int lim) { historyLimit_ = lim; }
 
-    int getRingingTimeout() const { return ringingTimeout_; }
+    std::chrono::seconds getRingingTimeout() const { return std::chrono::seconds(ringingTimeout_); }
 
-    void setRingingTimeout(int timeout) { ringingTimeout_ = timeout; }
+    void setRingingTimeout(std::chrono::seconds timeout) { ringingTimeout_ = timeout.count(); }
 
     int getHistoryMaxCalls() const { return historyMaxCalls_; }
 
@@ -95,6 +100,7 @@ private:
     int portNum_;
     bool searchBarDisplay_;
     bool md5Hash_;
+    std::set<std::string> pendingAccountIds_;
     constexpr static const char* const CONFIG_LABEL = "preferences";
 };
 
@@ -229,7 +235,7 @@ public:
 
     const std::string& getEchoCanceller() const { return echoCanceller_; }
 
-    void setEchoCancel(std::string& canceller) { echoCanceller_ = canceller; }
+    void setEchoCancel(const std::string& canceller) { echoCanceller_ = canceller; }
 
 private:
     std::string audioApi_;
