@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,9 +19,8 @@
 
 static gnutls_session_t captured_tls_session = nullptr;
 
-
-
-void post_gnutls_init_hook(const gnutls_session_t session)
+void
+post_gnutls_init_hook(const gnutls_session_t session)
 {
-        captured_tls_session = session;
+    captured_tls_session = session;
 }
