@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -93,10 +93,10 @@ private:
                                   const std::string& callId,
                                   const std::string& state,
                                   CallData& callData);
-    static void onIncomingCallWithMedia(const std::string& accountId,
-                                        const std::string& callId,
-                                        const std::vector<libjami::MediaMap> mediaList,
-                                        CallData& callData);
+    static void onIncomingCall(const std::string& accountId,
+                               const std::string& callId,
+                               const std::vector<libjami::MediaMap> mediaList,
+                               CallData& callData);
     static void onMediaNegotiationStatus(const std::string& callId, const std::string& event, CallData& callData);
 
     // Helpers
@@ -190,15 +190,15 @@ SipSrtpTest::getUserAlias(const std::string& callId)
 }
 
 void
-SipSrtpTest::onIncomingCallWithMedia(const std::string& accountId,
-                                     const std::string& callId,
-                                     const std::vector<libjami::MediaMap> mediaList,
-                                     CallData& callData)
+SipSrtpTest::onIncomingCall(const std::string& accountId,
+                            const std::string& callId,
+                            const std::vector<libjami::MediaMap> mediaList,
+                            CallData& callData)
 {
     CPPUNIT_ASSERT_EQUAL(callData.accountId_, accountId);
 
     JAMI_INFO("Signal [%s] - user [%s] - call [%s] - media count [%lu]",
-              libjami::CallSignal::IncomingCallWithMedia::name,
+              libjami::CallSignal::IncomingCall::name,
               callData.alias_.c_str(),
               callId.c_str(),
               mediaList.size());
@@ -216,7 +216,7 @@ SipSrtpTest::onIncomingCallWithMedia(const std::string& accountId,
 
     std::unique_lock lock {callData.mtx_};
     callData.callId_ = callId;
-    callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::IncomingCallWithMedia::name));
+    callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::IncomingCall::name));
 
     callData.cv_.notify_one();
 }
@@ -356,14 +356,14 @@ SipSrtpTest::configureTest(CallData& aliceData, CallData& bobData)
     std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> signalHandlers;
 
     // Insert needed signal handlers.
-    signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::IncomingCallWithMedia>(
+    signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::IncomingCall>(
         [&](const std::string& accountId,
             const std::string& callId,
             const std::string&,
             const std::vector<libjami::MediaMap> mediaList) {
             auto user = getUserAlias(callId);
             if (not user.empty())
-                onIncomingCallWithMedia(accountId, callId, mediaList, user == aliceData.alias_ ? aliceData : bobData);
+                onIncomingCall(accountId, callId, mediaList, user == aliceData.alias_ ? aliceData : bobData);
         }));
 
     signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::StateChange>(
@@ -413,7 +413,7 @@ SipSrtpTest::audio_video_call(std::vector<MediaAttribute> offer, std::vector<Med
     CPPUNIT_ASSERT(waitForSignal(aliceData_, libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
     // Wait for incoming call signal.
-    CPPUNIT_ASSERT(waitForSignal(bobData_, libjami::CallSignal::IncomingCallWithMedia::name));
+    CPPUNIT_ASSERT(waitForSignal(bobData_, libjami::CallSignal::IncomingCall::name));
 
     // Answer the call.
     libjami::acceptWithMedia(bobData_.accountId_, bobData_.callId_, MediaAttribute::mediaAttributesToMediaMaps(answer));
