@@ -1,6 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2018-2024 Savoir-faire Linux Inc.                       *
- *   Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>       *
+ *   Copyright (C) 2018-2026 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -38,7 +37,7 @@ namespace api {
 class BehaviorController;
 
 namespace datatransfer {
-class Info;
+struct Info;
 } // namespace datatransfer
 
 /**
