@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2017-2026 Savoir-faire Linux Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -191,6 +191,16 @@ public:
     QList<call::PendingConferenceeInfo> pendingConferencees_;
     QString waitForConference_ {};
 
+private:
+    // Tracks last known participant count per conference to detect size changes in slotOnConferenceInfosUpdated.
+    std::map<QString, size_t> previousCallListSizes_;
+
+    void applyFallbackConversationSwitch(const QString& confId,
+                                         OptRef<conversation::Info> currentConversation,
+                                         OptRef<conversation::Info> fallbackConversation,
+                                         const QString& newCallId,
+                                         const QString& newConfId);
+
 public Q_SLOTS:
     /**
      * Connect this signal to know when a call arrives
@@ -201,6 +211,17 @@ public Q_SLOTS:
     void slotMediaChangeRequested(const QString& accountId,
                                   const QString& callId,
                                   const VectorMapStringString& mediaList);
+    /**
+     * Listen from CallbacksHandler when a call arrives
+     * @param accountId
+     * @param callId
+     * @param from
+     * @param mediaList
+     */
+    void slotIncomingCall(const QString& accountId,
+                          const QString& callId,
+                          const QString& from,
+                          const VectorMapStringString& mediaList);
     /**
      * Listen from CallbacksHandler when a call got a new state
      * @param accountId
@@ -362,8 +383,8 @@ CallModel::setVideoMuted(const QString& callId, bool videoMuted)
     }
 }
 
-static void
-initializeMediaList(VectorMapStringString& mediaList, bool audioOnly)
+void
+initializeMediaList(VectorMapStringString& mediaList, bool audioOnly, bool videoMuted)
 {
     mediaList.push_back({{MediaAttributeKey::MEDIA_TYPE, MediaAttributeValue::AUDIO},
                          {MediaAttributeKey::ENABLED, TRUE_STR},
@@ -372,6 +393,15 @@ initializeMediaList(VectorMapStringString& mediaList, bool audioOnly)
                          {MediaAttributeKey::LABEL, "audio_0"}});
     if (audioOnly)
         return;
+    if (videoMuted) {
+        mediaList.push_back({{MediaAttributeKey::MEDIA_TYPE, MediaAttributeValue::VIDEO},
+                             {MediaAttributeKey::ENABLED, TRUE_STR},
+                             {MediaAttributeKey::MUTED, TRUE_STR},
+                             {MediaAttributeKey::SOURCE, ""},
+                             {MediaAttributeKey::LABEL, "video_0"}});
+        return;
+    }
+
     const auto defaultCamera = VideoManager::instance().getDefaultDevice();
     QString cameraMRL = "camera://" + defaultCamera;
     mediaList.push_back({{MediaAttributeKey::MEDIA_TYPE, MediaAttributeValue::VIDEO},
@@ -383,10 +413,11 @@ initializeMediaList(VectorMapStringString& mediaList, bool audioOnly)
 }
 
 QString
-CallModel::createCall(const QString& uri, bool isAudioOnly, VectorMapStringString mediaList)
+CallModel::createCall(const QString& uri, bool isAudioOnly, VectorMapStringString mediaList, bool videoMuted)
 {
+    bool isSwarm = uri.startsWith("swarm:") || uri.startsWith("rdv:");
     if (mediaList.isEmpty()) {
-        initializeMediaList(mediaList, isAudioOnly);
+        initializeMediaList(mediaList, isAudioOnly, videoMuted && isSwarm);
     }
 #ifdef ENABLE_LIBWRAP
     auto callId = CallManager::instance().placeCallWithMedia(owner.id, uri, mediaList);
@@ -396,7 +427,7 @@ CallModel::createCall(const QString& uri, bool isAudioOnly, VectorMapStringStrin
 #endif // ENABLE_LIBWRAP
 
     if (callId.isEmpty()) {
-        if (uri.startsWith("swarm:")) {
+        if (isSwarm) {
             pimpl_->waitForConference_ = uri;
             return {};
         }
@@ -411,7 +442,7 @@ CallModel::createCall(const QString& uri, bool isAudioOnly, VectorMapStringStrin
     callInfo->status = call::Status::SEARCHING;
     callInfo->type = call::Type::DIALOG;
     callInfo->isAudioOnly = isAudioOnly;
-    callInfo->videoMuted = isAudioOnly;
+    callInfo->videoMuted = videoMuted;
     callInfo->mediaList = mediaList;
     pimpl_->calls.emplace(callId, std::move(callInfo));
 
@@ -874,7 +905,21 @@ CallModel::joinCalls(const QString& callIdA, const QString& callIdB) const
 QString
 CallModel::callAndAddParticipant(const QString uri, const QString& callId, bool audioOnly)
 {
-    auto newCallId = createCall(uri, audioOnly, pimpl_->calls[callId]->mediaList);
+    // When adding a participant, only offer a single audio stream.
+    // The existing call may have multiple audio streams, but new
+    // participants should negotiate one audio stream with the conference
+    // host, which handles mixing internally.
+    VectorMapStringString mediaList;
+    bool audioAdded = false;
+    for (const auto& media : pimpl_->calls[callId]->mediaList) {
+        if (media[libjami::Media::MediaAttributeKey::MEDIA_TYPE] == libjami::Media::MediaAttributeValue::AUDIO) {
+            if (audioAdded)
+                continue;
+            audioAdded = true;
+        }
+        mediaList.push_back(media);
+    }
+    auto newCallId = createCall(uri, audioOnly, mediaList);
     Q_EMIT beginInsertPendingConferenceesRows(0);
     pimpl_->pendingConferencees_.prepend({uri, newCallId, callId});
     Q_EMIT endInsertPendingConferenceesRows();
@@ -956,6 +1001,46 @@ CallModel::getCurrentRenderedDevice(const QString& call_id) const
     return result;
 }
 
+std::optional<QString>
+CallModel::computeFallbackConversation(bool currentIsCoreDialog,
+                                       const QString& currentConversationUid,
+                                       const QStringList& remoteParticipantUris,
+                                       const QMap<QString, QString>& peerUriToConversationUid)
+{
+    if (!currentIsCoreDialog) {
+        return std::nullopt;
+    }
+
+    if (remoteParticipantUris.isEmpty()) {
+        return std::nullopt;
+    }
+
+    QString fallbackUid;
+
+    for (const auto& uri : remoteParticipantUris) {
+        auto it = peerUriToConversationUid.constFind(uri);
+        if (it == peerUriToConversationUid.constEnd() || it.value().isEmpty()) {
+            continue;
+        }
+
+        // If any remaining participant maps to the current conversation then no switch needed
+        if (it.value() == currentConversationUid) {
+            return std::nullopt;
+        }
+
+        // Otherwise remember the first available conversation candidate
+        if (fallbackUid.isEmpty()) {
+            fallbackUid = it.value();
+        }
+    }
+
+    if (fallbackUid.isEmpty()) {
+        return std::nullopt;
+    }
+
+    return fallbackUid;
+}
+
 QString
 CallModel::getDisplay(int idx, int x, int y, int w, int h)
 {
@@ -1011,6 +1096,7 @@ CallModelPimpl::CallModelPimpl(const CallModel& linked,
     , behaviorController(behaviorController)
 {
     connect(&callbacksHandler, &CallbacksHandler::mediaChangeRequested, this, &CallModelPimpl::slotMediaChangeRequested);
+    connect(&callbacksHandler, &CallbacksHandler::incomingCall, this, &CallModelPimpl::slotIncomingCall);
     connect(&callbacksHandler, &CallbacksHandler::callStateChanged, this, &CallModelPimpl::slotCallStateChanged);
     connect(&callbacksHandler,
             &CallbacksHandler::mediaNegotiationStatus,
@@ -1030,6 +1116,7 @@ CallModelPimpl::CallModelPimpl(const CallModel& linked,
             this,
             &CallModelPimpl::onRemoteRecordingChanged);
     connect(&callbacksHandler, &CallbacksHandler::recordingStateChanged, this, &CallModelPimpl::onRecordingStateChanged);
+    connect(&callbacksHandler, &CallbacksHandler::recordingStateChanged, this, &CallModelPimpl::onRecordingStateChanged);
 
 #ifndef ENABLE_LIBWRAP
     // Only necessary with D-Bus since the daemon runs separately
@@ -1083,40 +1170,69 @@ CallModelPimpl::getFallbackConversationForConference(const QString& confId)
         return std::nullopt;
     }
 
-    const auto participantsIt = participantsModel.find(confId);
-    if (participantsIt == participantsModel.end()) {
-        qWarning() << "No participants model found for conference ID:" << confId;
-        return std::nullopt;
-    }
-
-    // There should always be at least 2 participants in a SIP call/conference
-    const auto participants = participantsIt->second->getParticipants();
-    if (participants.size() <= 1) {
-        qWarning() << participants.size() << "participants found in conference" << confId
-                   << ", no fallback conversation available.";
-        return std::nullopt;
-    }
-
-    // Check if any participant matches the current conversation
-    // If yes, then no need to switch conversation, so return nullopt
-    for (const auto& participant : participants) {
-        const auto conv = linked.owner.conversationModel->getConversationForPeerUri(participant.uri);
-        if (conv && currentConversation->get().uid == conv->get().uid) {
-            qDebug() << "Current conversation matches a participant. No fallback needed.";
-            return std::nullopt;
+    // Collect remote participants (excluding self, avoid duplicates)
+    // participantsModel is populated from confInfos, which is entirely handled by the videomixer
+    // and based on active RTP streams. It can be unreliable during transitions (e.g. camera activation)
+    // where streams are temporarily missing.
+    // Therefore a stable API from the daemon based on subcalls would be nice
+    QStringList remoteParticipantsUris;
+    auto participantIt = participantsModel.find(confId);
+    if (participantIt != participantsModel.end() && participantIt->second) {
+        for (const auto& participant : participantIt->second->getParticipants()) {
+            auto uri = participant.uri;
+            if (uri != linked.owner.profileInfo.uri && !remoteParticipantsUris.contains(uri)) {
+                remoteParticipantsUris.append(uri);
+            }
         }
     }
 
-    OptRef<conversation::Info> fallbackConversation = std::nullopt;
-    for (const auto& participant : participants) {
-        if (participant.uri != linked.owner.profileInfo.uri) {
-            fallbackConversation = linked.owner.conversationModel->getConversationForPeerUri(participant.uri);
-            qDebug() << "Fallback conversation found with URI:" << participant.uri;
-            break;
+    QMap<QString, QString> peerUriToConversationUid;
+    for (const auto& uri : remoteParticipantsUris) {
+        const auto conv = linked.owner.conversationModel->getConversationForPeerUri(uri);
+        if (conv) {
+            peerUriToConversationUid.insert(uri, conv->get().uid);
         }
     }
 
-    return fallbackConversation;
+    auto fallbackUid = CallModel::computeFallbackConversation(currentConversation->get().isCoreDialog(),
+                                                              currentConversation->get().uid,
+                                                              remoteParticipantsUris,
+                                                              peerUriToConversationUid);
+    if (!fallbackUid) {
+        return std::nullopt;
+    }
+
+    auto fallbackConv = linked.owner.conversationModel->getConversationForUid(fallbackUid.value());
+    if (!fallbackConv) {
+        qWarning() << "Fallback conversation UID chosen but not found:" << fallbackUid.value();
+        return std::nullopt;
+    }
+
+    qWarning() << "Fallback conversation found with UID:" << fallbackUid.value();
+    return fallbackConv;
+}
+
+void
+CallModelPimpl::applyFallbackConversationSwitch(const QString& confId,
+                                                OptRef<conversation::Info> currentConversation,
+                                                OptRef<conversation::Info> fallbackConversation,
+                                                const QString& newCallId,
+                                                const QString& newConfId)
+{
+    if (!fallbackConversation) {
+        return;
+    }
+
+    if (currentConversation) {
+        currentConversation->get().confId.clear();
+    }
+
+    fallbackConversation->get().confId = newConfId;
+    fallbackConversation->get().callId = newCallId;
+
+    qWarning() << "[conf:" << confId << "] Switching to conversation:" << fallbackConversation->get().uid;
+    linked.owner.conversationModel->selectConversation(fallbackConversation->get().uid);
+    Q_EMIT linked.fallbackConversationSelected(linked.owner.id, fallbackConversation->get().uid);
 }
 
 QStringList
@@ -1433,6 +1549,88 @@ CallModelPimpl::slotMediaChangeRequested(const QString& accountId,
                                                      QVector<MapStringString>::fromList(answerMedia));
 }
 
+void
+CallModelPimpl::slotIncomingCall(const QString& accountId,
+                                 const QString& callId,
+                                 const QString& from,
+                                 const VectorMapStringString& mediaList)
+{
+    if (accountId != linked.owner.id)
+        return;
+
+    if (linked.hasCall(callId)) {
+        qWarning() << "Did not initialize incoming call" << callId << "because it already exists";
+        return;
+    }
+
+    auto callInfo = std::make_shared<call::Info>();
+    callInfo->id = callId;
+
+    MapStringString details = CallManager::instance().getCallDetails(linked.owner.id, callId);
+
+    if (details.isEmpty()) {
+        callInfo->peerUri = from;
+        callInfo->isOutgoing = false;
+        callInfo->status = call::Status::INCOMING_RINGING;
+        callInfo->type = call::Type::DIALOG;
+        bool hasVideo = false;
+        for (const auto& media : mediaList) {
+            if (media.value(MediaAttributeKey::MEDIA_TYPE) == MediaAttributeValue::VIDEO) {
+                hasVideo = true;
+                break;
+            }
+        }
+        callInfo->isAudioOnly = !hasVideo;
+        callInfo->videoMuted = !hasVideo;
+        initializeMediaList(callInfo->mediaList, callInfo->isAudioOnly, callInfo->videoMuted);
+    } else {
+        auto endId = details["PEER_NUMBER"].indexOf("@");
+        callInfo->peerUri = details["PEER_NUMBER"].left(endId);
+        callInfo->isOutgoing = details["CALL_TYPE"] == "1";
+        callInfo->status = call::Status::INCOMING_RINGING;
+        callInfo->type = call::Type::DIALOG;
+        callInfo->isAudioOnly = details["AUDIO_ONLY"] == TRUE_STR;
+        callInfo->videoMuted = details["VIDEO_MUTED"] == TRUE_STR;
+        initializeMediaList(callInfo->mediaList, callInfo->isAudioOnly, callInfo->videoMuted);
+    }
+
+    calls.emplace(callId, std::move(callInfo));
+
+    if (!(details["CALL_TYPE"] == "1") && !linked.owner.confProperties.allowIncoming
+        && linked.owner.profileInfo.type == profile::Type::JAMI) {
+        linked.decline(callId);
+        return;
+    }
+
+    QString displayname;
+    QString peerId;
+    QString peerUri = details.isEmpty() ? from : details["PEER_NUMBER"];
+    QString toUsername = details.isEmpty() ? "" : details["TO_USERNAME"];
+
+    if (peerUri.contains("ring.dht")) {
+        peerId = peerUri.right(50);
+        peerId = peerId.left(40);
+        if (!details.isEmpty())
+            displayname = details["REGISTERED_NAME"];
+    } else {
+        auto left = std::max(peerUri.indexOf("<"), peerUri.indexOf(":")) + 1;
+        auto right = peerUri.indexOf("@");
+        right = std::max(right, peerUri.indexOf(">"));
+        peerId = peerUri.mid(left, right - left);
+        if (!details.isEmpty())
+            displayname = details["DISPLAY_NAME"];
+        if (displayname.isEmpty())
+            displayname = peerId;
+    }
+
+    qWarning() << "Initialized incoming call" << callId << "from peer" << peerId;
+
+    Q_EMIT linked.newCall(peerId, callId, displayname, false, toUsername);
+
+    Q_EMIT linked.callStatusChanged(accountId, callId, 0);
+    Q_EMIT behaviorController.callStatusChanged(linked.owner.id, callId);
+}
+
 void
 CallModelPimpl::slotCallStateChanged(const QString& accountId, const QString& callId, const QString& state, int code)
 {
@@ -1440,54 +1638,8 @@ CallModelPimpl::slotCallStateChanged(const QString& accountId, const QString& ca
         return;
 
     if (!linked.hasCall(callId)) {
-        auto callInfo = std::make_shared<call::Info>();
-        callInfo->id = callId;
-        MapStringString details = CallManager::instance().getCallDetails(linked.owner.id, callId);
-        qDebug() << details;
-
-        auto endId = details["PEER_NUMBER"].indexOf("@");
-        callInfo->peerUri = details["PEER_NUMBER"].left(endId);
-        callInfo->isOutgoing = details["CALL_TYPE"] == "1";
-        callInfo->status = call::to_status(state);
-        callInfo->type = call::Type::DIALOG;
-        callInfo->isAudioOnly = details["AUDIO_ONLY"] == TRUE_STR;
-        callInfo->videoMuted = details["VIDEO_MUTED"] == TRUE_STR;
-        // NOTE: The CallModel::setVideoMuted function currently relies on callInfo->mediaList
-        // having been initialized. Not doing so leads to a bug where the user's camera wrongly
-        // gets turned on when they receive a call and click on "Answer in audio".
-        initializeMediaList(callInfo->mediaList, callInfo->isAudioOnly);
-        calls.emplace(callId, std::move(callInfo));
-
-        if (!(details["CALL_TYPE"] == "1") && !linked.owner.confProperties.allowIncoming
-            && linked.owner.profileInfo.type == profile::Type::JAMI) {
-            linked.decline(callId);
-            return;
-        }
-
-        QString displayname = details["DISPLAY_NAME"];
-        QString peerId;
-        QString peerUri = details["PEER_NUMBER"];
-        if (peerUri.contains("ring.dht")) {
-            peerId = peerUri.right(50);
-            peerId = peerId.left(40);
-            if (displayname.isEmpty())
-                displayname = details["REGISTERED_NAME"];
-        } else {
-            auto left = std::max(peerUri.indexOf("<"), peerUri.indexOf(":")) + 1;
-            auto right = peerUri.indexOf("@");
-            right = std::max(right, peerUri.indexOf(">"));
-            peerId = peerUri.mid(left, right - left);
-            if (displayname.isEmpty())
-                displayname = peerId;
-        }
-        qDebug() << displayname;
-        qDebug() << peerId;
-
-        Q_EMIT linked.newCall(peerId, callId, displayname, details["CALL_TYPE"] == "1", details["TO_USERNAME"]);
-
-        // NOTE: signal emission order matters, always emit CallStatusChanged before CallEnded
-        Q_EMIT linked.callStatusChanged(accountId, callId, code);
-        Q_EMIT behaviorController.callStatusChanged(linked.owner.id, callId);
+        qWarning() << "slotCallStateChanged: unknown callId " << callId;
+        return;
     }
 
     auto status = call::to_status(state);
@@ -1641,7 +1793,14 @@ CallModelPimpl::slotOnConferenceInfosUpdated(const QString& confId, const Vector
     // For now, the rendez-vous account can see ongoing calls
     // And must be notified when a new
     QStringList callList = CallManager::instance().getParticipantList(linked.owner.id, confId);
-    qDebug() << "[conf:" << confId << "] Conference infos updated. Calls remaining:" << callList.size();
+    const auto callListSize = static_cast<size_t>(callList.size());
+    const auto previousCallListSizeIt = previousCallListSizes_.find(confId);
+    const auto previousCallListSize = previousCallListSizeIt != previousCallListSizes_.end()
+                                          ? previousCallListSizeIt->second
+                                          : 0;
+    previousCallListSizes_[confId] = callListSize;
+
+    qDebug() << "[conf:" << confId << "] Conference infos updated. Calls remaining:" << callListSize;
     Q_FOREACH (const auto& call, callList) {
         Q_EMIT linked.callAddedToConference(call, "", confId);
         if (calls.find(call) == calls.end()) {
@@ -1661,37 +1820,33 @@ CallModelPimpl::slotOnConferenceInfosUpdated(const QString& confId, const Vector
         participantIt->second->update(infos);
     it->second->layout = participantIt->second->getLayout();
 
-    // Check if we need to switch conversation
-    auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
-    if (currentConversation && callList.size() >= 2) {
-        auto fallbackConversation = getFallbackConversationForConference(confId);
-        // If a fallback conversation was returned, switch to it
-        if (fallbackConversation) {
-            currentConversation->get().confId.clear();
-            fallbackConversation->get().confId = confId;
-            fallbackConversation->get().callId = confId;
-            qWarning() << "[conf:" << confId
-                       << "] Switching to fallback conversation:" << fallbackConversation->get().uid;
-            linked.owner.conversationModel->selectConversation(fallbackConversation->get().uid);
-        }
-    }
-
     // if Jami, remove @ring.dht
-    for (auto& i : participantIt->second->getParticipants()) {
-        i.uri.replace("@ring.dht", "");
-        if (i.uri.isEmpty()) {
+    for (auto& participant : participantIt->second->getParticipants()) {
+        participant.uri.replace("@ring.dht", "");
+        if (participant.uri.isEmpty()) {
             if (it->second->type == call::Type::CONFERENCE) {
-                i.uri = linked.owner.profileInfo.uri;
+                participant.uri = linked.owner.profileInfo.uri;
             } else {
-                i.uri = it->second->peerUri.replace("ring:", "");
+                participant.uri = it->second->peerUri.replace("ring:", "");
             }
         }
     }
 
-    for (auto& info : infos) {
-        if (info["uri"].isEmpty()) {
-            it->second->videoMuted = info["videoMuted"] == TRUE_STR;
-            it->second->audioMuted = info["audioLocalMuted"] == TRUE_STR;
+    // If the conference only has 1 subcall left and getting destroyed, it will be handled by slotConferenceRemoved
+    // Otherwise, if the callist size decreased, we need to check if we need to switch conversation
+    bool participantHasLeft = previousCallListSize > callListSize;
+    bool conferenceIsOngoing = callListSize > 1;
+    if (participantHasLeft && conferenceIsOngoing) {
+        if (auto fallbackConversation = getFallbackConversationForConference(confId)) {
+            auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
+            applyFallbackConversationSwitch(confId, currentConversation, fallbackConversation, confId, confId);
+        }
+    }
+
+    for (auto& participantInfo : infos) {
+        if (participantInfo["uri"].isEmpty()) {
+            it->second->videoMuted = participantInfo["videoMuted"] == TRUE_STR;
+            it->second->audioMuted = participantInfo["audioLocalMuted"] == TRUE_STR;
         }
     }
 
@@ -1776,72 +1931,58 @@ CallModelPimpl::slotConferenceRemoved(const QString& accountId, const QString& c
     if (accountId != linked.owner.id || !linked.owner.conversationModel) {
         return;
     }
+
     auto confIt = calls.find(confId);
     if (confIt == calls.end() || !confIt->second) {
         return;
     }
 
     qWarning() << "[conf:" << confId
-               << "] Conference removed, determining remaining participant to switch conversation.";
+               << "] Destroying conference, determining whether a conversation switch is necessary.";
 
-    QString remainingPeerUri;
     QString remainingCallId;
 
-    auto participantsIt = participantsModel.find(confId);
-    if (participantsIt != participantsModel.end()) {
-        const auto participants = participantsIt->second->getParticipants();
-        // Assuming the participants model is up to date, it should contain all remaining participants in the conference
-        // Which should be 2: the host and the remaining remote peer
-        // Therefore, we look for the participant which is not ourselves
-        for (const auto& participant : participants) {
+    // Find the remaining call's id
+    auto participantIt = participantsModel.find(confId);
+    if (participantIt != participantsModel.end() && participantIt->second) {
+        for (const auto& participant : participantIt->second->getParticipants()) {
             if (participant.uri != linked.owner.profileInfo.uri) {
-                remainingPeerUri = participant.uri;
-                try {
-                    remainingCallId = linked.getCallFromURI(remainingPeerUri, true).id;
-                } catch (const std::exception& e) {
-                    qWarning() << "[conf:" << confId << "] Could not find call for peerUri:" << remainingPeerUri << ":"
-                               << e.what();
-                }
+                // getCallFromURI will throw an std::out_of_range if the call is not found
+                // however it is not this function's responsibility to guarantee that the call exists
+                // so we let the exception propagate if it occurs
+                remainingCallId = linked.getCallFromURI(participant.uri, true).id;
                 break;
             }
         }
+    } else if (participantIt == participantsModel.end()) {
+        qWarning() << "[conf:" << confId << "] No participants model found for conference.";
     } else {
-        qWarning() << "[conf:" << confId << "] Participants model not found for conference";
+        qWarning() << "[conf:" << confId << "] Participants model is null.";
     }
 
     auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
     auto fallbackConversation = getFallbackConversationForConference(confId);
-    // If we have a fallback conversation, that means the client should switch to it
+
+    // If a fallback conversation was returned, we should switch to it
     if (fallbackConversation) {
-        if (currentConversation) {
-            currentConversation->get().confId.clear();
-        }
-        auto& targetConv = fallbackConversation->get();
-        targetConv.confId.clear();
-        if (!remainingCallId.isEmpty()) {
-            targetConv.callId = remainingCallId;
-        }
-        qWarning() << "[conf:" << confId << "] Switching to conversation:" << targetConv.uid;
-        linked.owner.conversationModel->selectConversation(targetConv.uid);
+        applyFallbackConversationSwitch(confId, currentConversation, fallbackConversation, remainingCallId, QString {});
     } else if (currentConversation) {
-        auto& targetConv = currentConversation->get();
-        targetConv.confId.clear();
-        if (!remainingCallId.isEmpty()) {
-            targetConv.callId = remainingCallId;
-        }
-        qWarning() << "[conf:" << confId << "] Staying in current conversation:" << targetConv.uid;
+        currentConversation->get().confId.clear();
+        currentConversation->get().callId = remainingCallId;
+        qWarning() << "[conf:" << confId << "] Staying in current conversation:" << currentConversation->get().uid;
     } else {
-        qWarning() << "[conf:" << confId << "] No conversation available to update after conference removal";
+        qWarning() << "[conf:" << confId << "] No conversation to switch to";
     }
 
     // Now remove the conference from our models and list of calls then update currentCall_
     participantsModel.erase(confId);
     calls.erase(confIt);
+    previousCallListSizes_.erase(confId);
 
     currentCall_ = remainingCallId;
     Q_EMIT linked.currentCallChanged(currentCall_);
 
-    qDebug() << "[conf:" << confId << "] Conference removed, transitioned to call" << currentCall_;
+    qDebug() << "[conf:" << confId << "] Conference removed, now staying on call" << currentCall_;
 }
 
 void
