@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Savoir-faire Linux Inc.
+ * Copyright (C) 2014-2026 Savoir-faire Linux Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -106,7 +106,10 @@ public:
                                         QString(accountId.c_str()),
                                         QString(callId.c_str()),
                                         QString(from.c_str()));
-                    Q_EMIT incomingCall(QString(accountId.c_str()), QString(callId.c_str()), QString(from.c_str()));
+                    Q_EMIT incomingCall(QString(accountId.c_str()),
+                                        QString(callId.c_str()),
+                                        QString(from.c_str()),
+                                        convertVecMap(mediaList));
                 }),
             exportable_callback<CallSignal::MediaChangeRequested>(
                 [this](const std::string& accountId,
@@ -181,10 +184,6 @@ public:
                 LOG_LIBJAMI_SIGNAL2("videoMuted", QString(callId.c_str()), state);
                 Q_EMIT videoMuted(QString(callId.c_str()), state);
             }),
-            exportable_callback<CallSignal::SmartInfo>([this](const std::map<std::string, std::string>& info) {
-                LOG_LIBJAMI_SIGNAL("SmartInfo", "");
-                Q_EMIT SmartInfo(convertMap(info));
-            }),
             exportable_callback<CallSignal::RemoteRecordingChanged>(
                 [this](const std::string& callId, const std::string& contactId, bool state) {
                     LOG_LIBJAMI_SIGNAL3("remoteRecordingChanged",
@@ -445,16 +444,6 @@ public Q_SLOTS: // METHODS
         return libjami::muteLocalMedia(accountId.toStdString(), callId.toStdString(), mediaType.toStdString(), mute);
     }
 
-    void startSmartInfo(int refresh)
-    {
-        libjami::startSmartInfo(refresh);
-    }
-
-    void stopSmartInfo()
-    {
-        libjami::stopSmartInfo();
-    }
-
     void setConferenceLayout(const QString& accountId, const QString& confId, int layout)
     {
         libjami::setConferenceLayout(accountId.toStdString(), confId.toStdString(), layout);
@@ -547,7 +536,10 @@ Q_SIGNALS: // SIGNALS
                          const QString& callId,
                          const QString& from,
                          const MapStringString& message);
-    void incomingCall(const QString& accountId, const QString& callId, const QString& from);
+    void incomingCall(const QString& accountId,
+                      const QString& callId,
+                      const QString& from,
+                      const VectorMapStringString& mediaList);
     void mediaChangeRequested(const QString& accountId, const QString& callId, const VectorMapStringString& mediaList);
     void recordPlaybackFilepath(const QString& callId, const QString& filepath);
     void conferenceCreated(const QString& accountId, const QString& conversationId, const QString& confId);
@@ -560,7 +552,6 @@ Q_SIGNALS: // SIGNALS
     void audioMuted(const QString& callId, bool state);
     void videoMuted(const QString& callId, bool state);
     void peerHold(const QString& callId, bool state);
-    void SmartInfo(const MapStringString& info);
     void remoteRecordingChanged(const QString& callId, const QString& peerNumber, bool remoteRecordingState);
 };
 
