@@ -1,22 +1,5 @@
-/*
- *  Copyright (C) 2014-2025 Savoir-faire Linux Inc.
- *
- *  Author: Vsevolod Ivanov <vsevolod.ivanov@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <https://www.gnu.org/licenses/>.
- */
-
+// Copyright (c) 2014-2026 Savoir-faire Linux Inc.
+// SPDX-License-Identifier: MIT
 #pragma once
 
 // cppunit
@@ -32,7 +15,8 @@
 
 namespace test {
 
-class HttpTester : public CppUnit::TestFixture {
+class HttpTester : public CppUnit::TestFixture
+{
     CPPUNIT_TEST_SUITE(HttpTester);
     // parse_url
     CPPUNIT_TEST(test_parse_url);
@@ -59,53 +43,53 @@ class HttpTester : public CppUnit::TestFixture {
     CPPUNIT_TEST(test_send_json);
     CPPUNIT_TEST_SUITE_END();
 
- public:
+public:
     /**
      * Method automatically called before each test by CppUnit
      * Init nodes
      */
-   void setUp();
+    void setUp();
     /**
      * Method automatically called after each test CppUnit
      */
-   void tearDown();
+    void tearDown();
     /**
      * Test parse urls
      */
-   void test_parse_url();
-   void test_parse_https_url_no_service();
-   void test_parse_url_no_prefix_no_target();
-   void test_parse_url_target();
-   void test_parse_url_query();
-   void test_parse_url_fragment();
+    void test_parse_url();
+    void test_parse_https_url_no_service();
+    void test_parse_url_no_prefix_no_target();
+    void test_parse_url_target();
+    void test_parse_url_query();
+    void test_parse_url_fragment();
     /**
      * Test parse urls (ipv4)
      */
-   void test_parse_url_ipv4();
-   void test_parse_url_no_prefix_no_target_ipv4();
-   void test_parse_url_target_ipv4();
+    void test_parse_url_ipv4();
+    void test_parse_url_no_prefix_no_target_ipv4();
+    void test_parse_url_target_ipv4();
     /**
      * Test parse urls (ipv6)
      */
-   void test_parse_url_ipv6();
-   void test_parse_url_no_prefix_no_target_ipv6();
-   void test_parse_url_target_ipv6();
-   void test_parse_url_user_pass();
-   void test_parse_url_user_only();
-   void test_parse_url_ipv6_brackets();
-   void test_parse_url_ipv6_brackets_port();
-   void test_parse_url_mixed_case_protocol();
-   void test_parse_url_complex_path_query_fragment();
-   void test_parse_url_empty();
-   void test_parse_url_just_slash();
+    void test_parse_url_ipv6();
+    void test_parse_url_no_prefix_no_target_ipv6();
+    void test_parse_url_target_ipv6();
+    void test_parse_url_user_pass();
+    void test_parse_url_user_only();
+    void test_parse_url_ipv6_brackets();
+    void test_parse_url_ipv6_brackets_port();
+    void test_parse_url_mixed_case_protocol();
+    void test_parse_url_complex_path_query_fragment();
+    void test_parse_url_empty();
+    void test_parse_url_just_slash();
     /**
      * Test send(json)
      */
-   void test_send_json();
+    void test_send_json();
 
- private:
+private:
     std::shared_ptr<dht::DhtRunner> nodePeer;
     std::unique_ptr<dht::DhtProxyServer> serverProxy;
 };
 
-}  // namespace test
+} // namespace test
