@@ -1,22 +1,5 @@
-/*
- *  Copyright (C) 2014-2025 Savoir-faire Linux Inc.
- *
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <https://www.gnu.org/licenses/>.
- */
-
+// Copyright (c) 2014-2026 Savoir-faire Linux Inc.
+// SPDX-License-Identifier: MIT
 #pragma once
 
 // cppunit
@@ -25,7 +8,8 @@
 
 namespace test {
 
-class InfoHashTester : public CppUnit::TestFixture {
+class InfoHashTester : public CppUnit::TestFixture
+{
     CPPUNIT_TEST_SUITE(InfoHashTester);
     CPPUNIT_TEST(testConstructors);
     CPPUNIT_TEST(testComparators);
@@ -35,7 +19,7 @@ class InfoHashTester : public CppUnit::TestFixture {
     CPPUNIT_TEST(testHex);
     CPPUNIT_TEST_SUITE_END();
 
- public:
+public:
     /**
      * Method automatically called before each test by CppUnit
      */
@@ -71,4 +55,4 @@ class InfoHashTester : public CppUnit::TestFixture {
     void testHex();
 };
 
-}  // namespace test
+} // namespace test
